# Development Scripts

The scripts follow GitHub's ["Scripts to Rule Them All"](https://github.com/github/scripts-to-rule-them-all).

Call them from the root of the project, e.g. `./scripts/lint.sh`.

- `scripts/format.sh` - Format the code to the required standards.
- `scripts/lint.sh` - Run the automated code linting/formatting tools.
- `scripts/release.sh` - Publish package to PyPI.
